Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/Ultimaker/Cura.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorJaime van Kessel <nallath@gmail.com>2016-07-04 18:11:03 +0300
committerJaime van Kessel <nallath@gmail.com>2016-07-04 18:11:03 +0300
commit318182495ae4874a6fa18b8ffbb992782f1ade80 (patch)
tree5968f07e48544738eb4c228ce2ca5f7e6bd99dae /plugins/CuraEngineBackend/Cura.proto
parent90fa0f05645c7e37577ea14d675deb5aba97bf4b (diff)
We now recieve material estimation per extruder
CURA-1687
Diffstat (limited to 'plugins/CuraEngineBackend/Cura.proto')
-rw-r--r--plugins/CuraEngineBackend/Cura.proto11
1 files changed, 8 insertions, 3 deletions
diff --git a/plugins/CuraEngineBackend/Cura.proto b/plugins/CuraEngineBackend/Cura.proto
index 38753fd804..5f95a4d4a8 100644
--- a/plugins/CuraEngineBackend/Cura.proto
+++ b/plugins/CuraEngineBackend/Cura.proto
@@ -65,10 +65,15 @@ message GCodeLayer {
bytes data = 2;
}
-message ObjectPrintTime { // The print time for the whole print and material estimates for the first extruder
+
+message PrintTimeMaterialEstimates { // The print time for the whole print and material estimates for the extruder
+ float time = 1; // Total time estimate
+ repeated MaterialEstimates materialEstimates = 2; // materialEstimates data
+}
+
+message MaterialEstimates {
int64 id = 1;
- float time = 2; // Total time estimate
- float material_amount = 3; // material used in the first extruder
+ float material_amount = 2; // material used in the extruder
}
message SettingList {